@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "easy-kill-extras" "0.9.15"
+(define-package "easy-kill-extras" "20260108.1716"
   "Extra functions for easy-kill."
   '((easy-kill "0.9.4"))
   :url "https://github.com/knu/easy-kill-extras.el"
-  :commit "7aad156fb9017facbe81076c00a07335ee1fec37"
-  :revdesc "7aad156fb901"
+  :commit "3fea06322d76be78e66074b9a9dad9a6d4aa6bcd"
+  :revdesc "3fea06322d76"
   :keywords '("killing" "convenience")
   :authors '(("Akinori MUSHA" . "knu@iDaemons.org"))
   :maintainers '(("Akinori MUSHA" . "knu@iDaemons.org")))
